<?php

/********************************************************************************************************************************
*
*  Reputation levels (/admin/modules/config/reputationlevels.php)
*  Author: Krzysztof "Supryk" Supryczyński 
*  Copyright: © 2013 - 2021 @ Krzysztof "Supryk" Supryczyński @ All rights reserved
*  
*  Website: http://supryk.eu/
*  Description: Add reputation title to postbit, member_profile and background for it.
*
********************************************************************************************************************************/
/********************************************************************************************************************************
*
* This file is part of "Reputation levels" plugin for MyBB.
* Copyright © 2013 - 2021 @ Krzysztof "Supryk" Supryczyński @ All rights reserved
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
********************************************************************************************************************************/

if(!defined("IN_MYBB"))
{
	die("Direct initialization of this file is not allowed.<br /><br />Please make sure IN_MYBB is defined.");
}

$page->add_breadcrumb_item($lang->reputationlevels, "index.php?module=config-reputationlevels"); 

if($mybb->get_input("action") == "add" || $mybb->get_input("action") == "edit" || !$mybb->get_input("action"))
{
    $sub_tabs['reputationlevels'] = array(
        'title' => $lang->reputationlevels,
        'link' => "index.php?module=config-reputationlevels",
        'description' => $lang->reputationlevels,
    );
	
    $sub_tabs['reputationlevels_add'] = array( 
        'title' => $lang->reputationlevels_add,
        'link' => "index.php?module=config-reputationlevels&amp;action=add", 
        'description' => $lang->reputationlevels_add_desc,
    );
}

if($mybb->get_input("action") == "add")
{
	if($mybb->request_method == "post")
	{
		if(!trim($mybb->get_input("title")))
		{
			$errors[] = $lang->reputationlevels_error_missing_title;
		}
		
		if(!trim(is_numeric($mybb->get_input("reputation", 1))))
		{
			$errors[] = $lang->reputationlevels_error_missing_reputation;
		}

		if(!$errors)
		{
			$reputationlevel = array(
				"title" 		  => $db->escape_string($mybb->get_input("title")),
				"reputation" => $db->escape_string($mybb->get_input("reputation", 1)),
			);
			
			$lid = $db->insert_query("reputationlevels", $reputationlevel);
			
			update_reputationlevels();

			log_admin_action($lid, $mybb->get_input("title"));

			flash_message($lang->reputationlevels_add_success, 'success');
			admin_redirect("index.php?module=config-reputationlevels");
		}
	}
	
	$page->add_breadcrumb_item($lang->reputationlevels_add);
	$page->output_header($lang->reputationlevels." - ".$lang->reputationlevels_add);
	
	$page->output_nav_tabs($sub_tabs, 'reputationlevels_add');
	
	$form = new Form("index.php?module=config-reputationlevels&amp;action=add", "post", "add");
	
	if($errors)
	{
		$page->output_inline_error($errors);
	}

	$form_container = new FormContainer($lang->reputationlevels_add);
	$form_container->output_row($lang->reputationlevels_title."<em> *</em>", $lang->reputationlevels_title_desc, $form->generate_text_box('title', $mybb->get_input("title"), array('id' => 'title')), 'title');
	$form_container->output_row($lang->reputationlevels_reputation."<em> *</em>", $lang->reputationlevels_reputation_desc, $form->generate_numeric_field('reputation', $mybb->get_input("reputation", 1), array('id' => 'reputation')), 'reputation');
	$form_container->end();

	$buttons[] = $form->generate_submit_button($lang->reputationlevels_add_save);

	$form->output_submit_wrapper($buttons);
	$form->end();

	$page->output_footer();
}


if($mybb->get_input("action") == "edit")
{
	$query = $db->simple_select("reputationlevels", "*", "lid='".$mybb->get_input('lid', 1)."'");
	$reputationlevel = $db->fetch_array($query);
	
	if(!$reputationlevel['lid'])
	{
		flash_message($lang->reputationlevels_edit_error, 'error');
		admin_redirect("index.php?module=config-reputationlevels");
	}

	if($mybb->request_method == "post")
	{
		if(!trim($mybb->get_input("title")))
		{
			$errors[] = $lang->reputationlevels_error_missing_title;
		}
		
		if(!trim(is_numeric($mybb->get_input("reputation", 1))))
		{
			$errors[] = $lang->reputationlevels_error_missing_reputation;
		}

		if(!$errors)
		{
			$reputationlevel_update = array(
				"title"			  => $db->escape_string($mybb->get_input("title")),
				"reputation" => $db->escape_string($mybb->get_input("reputation", 1)),
			);
			
			$db->update_query("reputationlevels", $reputationlevel_update, "rlid = ".$mybb->get_input('rlid', 1)."");
			
			update_reputationlevels();
			
			log_admin_action($reputationlevel['lid'], $mybb->get_input("title"));

			flash_message($lang->reputationlevels_edit_success, 'success');
			admin_redirect("index.php?module=config-reputationlevels");
		}
	}
	
	$page->add_breadcrumb_item($lang->reputationlevels_edit);
	$page->output_header($lang->reputationlevels." - ".$lang->reputationlevels_edit);
	
	$sub_tabs['reputationlevels_edit'] = array( 
        'title' => $lang->reputationlevels_edit, 
        'link' => "index.php?module=config-reputationlevels&amp;action=edit", 
        'description' => $lang->reputationlevels_edit_desc,
    );
	
	$page->output_nav_tabs($sub_tabs, 'reputationlevels_edit');
	
	$form = new Form("index.php?module=config-reputationlevels&amp;action=edit&amp;rid={$reputationlevel['lid']}", "post", "edit");
	
	if($errors)
	{
		$page->output_inline_error($errors);
	}
	else
	{
		$mybb->input = $reputationlevel;
	}

	$form_container = new FormContainer($lang->reputationlevels_edit);
	$form_container->output_row($lang->reputationlevels_title."<em> *</em>", $lang->reputationlevels_title_desc, $form->generate_text_box('title', $mybb->get_input("title"), array('id' => 'title')), 'title');
	$form_container->output_row($lang->reputationlevels_reputation."<em> *</em>", $lang->reputationlevels_reputation_desc, $form->generate_numeric_field('reputation', $mybb->get_input("reputation", 1), array('id' => 'reputation')), 'reputation');
	$form_container->end();

	$buttons[] = $form->generate_submit_button($lang->reputationlevels_edit_save);

	$form->output_submit_wrapper($buttons);
	$form->end();

	$page->output_footer();
}

if($mybb->get_input("action") == "delete")
{	
	if($mybb->get_input("no"))
	{
		admin_redirect("index.php?module=config-reputationlevels");
	}
	
	$query = $db->simple_select("reputationlevels", "*", "rid = '".$mybb->get_input('lid', 1)."'");
	$reputationlevel = $db->fetch_array($query);
	
	if(!$reputationlevel['lid'])
	{
		flash_message($lang->reputationlevels_delete_error, 'error');
		admin_redirect("index.php?module=config-reputationlevels");
	}

	if($mybb->request_method == "post")
	{
		$db->delete_query("reputationlevels", "lid='{$reputationlevel['lid']}'");
		
		update_reputationlevels();

		log_admin_action($reputationlevel['lid'], $reputationlevel['title']);

		flash_message($lang->reputationlevels_delete_success, 'success');
		admin_redirect("index.php?module=config-reputationlevels");
	}
	else
	{
		$page->output_confirm_action("index.php?module=config-reputationlevels&amp;action=delete&amp;rlid={$reputationlevel['lid']}", $lang->reputationlevels_confirm_delection);
	}
}

if($mybb->input['action'] == "update_reputationlevels" && $mybb->request_method == "post")
{
	if(!is_array($mybb->input['reputation']) || !is_array($mybb->input['title']))
	{
		admin_redirect("index.php?module=config-reputationlevels");
	}

	foreach($mybb->input['reputation'] as $lid => $reputation)
	{
		if(!trim(is_numeric($reputation)))
		{
			flash_message($lang->reputationlevels_error_missing_reputation, 'error');
			admin_redirect("index.php?module=config-reputationlevels");
		}
		
		$reputation_update = array(
			"reputation" => $db->escape_string($reputation),
		);
		
		$db->update_query("reputationlevels", $reputation_update, "lid='{$lid}'");
	}
	
	foreach($mybb->input['title'] as $lid => $title)
	{
		if(empty($title))
		{
			flash_message($lang->reputationlevels_error_missing_reputation, 'error');
			admin_redirect("index.php?module=config-reputationlevels");
		}
		
		$title_update = array(
			"title" => $db->escape_string($title),
		);
		
		$db->update_query("reputationlevels", $title_update, "lid='{$lid}'");
	}
	
	update_reputationlevels();
	
	log_admin_action();

	flash_message($lang->reputationlevels_data_success, 'success');
	admin_redirect("index.php?module=config-reputationlevels");
}

if(!$mybb->get_input("action"))
{
	$page->output_header($lang->reputationlevels);

	$page->output_nav_tabs($sub_tabs, 'reputationlevels');

	$form = new Form("index.php?module=config-reputationlevels&amp;action=update_reputationlevels", "post", "update_reputationlevels");
	
	$form_container = new FormContainer($lang->reputationlevels);
	
	$form_container->output_row_header($lang->reputationlevels_title, array('width' => '20%'));
	$form_container->output_row_header($lang->reputationlevels_reputation, array('width' => '70%'));
	$form_container->output_row_header($lang->reputationlevels_options, array('width' => '150', 'class' => 'align_center'));
	
	$query = $db->simple_select("reputationlevels", "*", "", array('order_by' => 'reputation'));
	while($reputationlevel = $db->fetch_array($query))
	{	
		$form_container->output_cell("<input type=\"text\" name=\"title[{$reputationlevel['lid']}]\" value=\"{$reputationlevel['title']}\" class=\"text_input\" style=\"width: 80%;\" />");
		$form_container->output_cell("<input type=\"number\" name=\"reputation[{$reputationlevel['lid']}]\" value=\"{$reputationlevel['reputation']}\" class=\"text_input\" style=\"width: 20%;\" />");
		$popup = new PopupMenu("reputationlevel_{$reputationlevel['lid']}", $lang->reputationlevels_options);
		$popup->add_item($lang->reputationlevels_option_edit, "index.php?module=config-reputationlevels&amp;action=edit&amp;lid={$reputationlevel['lid']}");
		$popup->add_item($lang->reputationlevels_option_delete, "index.php?module=config-reputationlevels&amp;action=delete&amp;lid={$reputationlevel['lid']}&amp;my_post_key={$mybb->post_code}", "return AdminCP.deleteConfirmation(this, '{$lang->reputationlevels_popup_confirm_deletion}')");
		$form_container->output_cell($popup->fetch(), array("class" => "align_center"));
		$form_container->construct_row();
	}
	
	if($form_container->num_rows() == 0)
	{
		$form_container->output_cell($lang->no_report_reasons, array('colspan' => 3));
		$form_container->construct_row();
	}

	$form_container->end();
	
	$buttons = array();
	$buttons[] = $form->generate_submit_button($lang->reputationlevels_data_save);
	$form->output_submit_wrapper($buttons);

	$form->end();

	$page->output_footer();
}