<?php

/********************************************************************************************************************************
*
*  Reputation levels (/inc/plugins/reputationlevels.php)
*  Author: Krzysztof "Supryk" Supryczyński
*  Copyright: © 2013 - 2021 @ Krzysztof "Supryk" Supryczyński @ All rights reserved
*  
*  Website: http://supryk.eu/
*  Description: Add reputation title to postbit, member_profile and background for it.
*
********************************************************************************************************************************/
/********************************************************************************************************************************
*
* This file is part of "Reputation levels" plugin for MyBB.
* Copyright © 2013 - 2021 @ Krzysztof "Supryk" Supryczyński @ All rights reserved
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
********************************************************************************************************************************/

if(!defined("IN_MYBB"))
{
	die("Direct initialization of this file is not allowed.<br /><br />Please make sure IN_MYBB is defined.");
}

$plugins->add_hook("admin_config_settings_manage", "reputationlevels_admin_lang_load");
$plugins->add_hook("admin_config_settings_change", "reputationlevels_admin_lang_load");
$plugins->add_hook("admin_config_settings_start", "reputationlevels_admin_lang_load");
$plugins->add_hook("admin_style_templates_set", "reputationlevels_admin_lang_load");
$plugins->add_hook("admin_config_menu", "reputationlevels_admin_config_menu");
$plugins->add_hook("admin_config_action_handler", "reputationlevels_admin_config_action_handler");
$plugins->add_hook("admin_config_permissions", "reputationlevels_admin_config_permissions");
$plugins->add_hook("postbit", "reputationlevels_postbit");
$plugins->add_hook("postbit_prev", "reputationlevels_postbit");
$plugins->add_hook("postbit_pm", "reputationlevels_postbit");
$plugins->add_hook("postbit_announcement", "reputationlevels_postbit");
$plugins->add_hook("member_profile_end", "reputationlevels_member_profile");
$plugins->add_hook("misc_start", "reputationlevels_misc");
$plugins->add_hook("global_start", "reputationlevels_global_start");
$plugins->add_hook("pre_output_page", "reputationlevels_pre_output_page");

function reputationlevels_info()
{
    global $lang;
    $lang->load("config_reputationlevels");
	
	$lang->reputationlevels_desc = "<form action=\"https://www.paypal.com/donate\" method=\"post\" target=\"_top\" style=\"float:right;\">
<input type=\"hidden\" name=\"hosted_button_id\" value=\"8YTUDFQN6XAGN\" />
<input type=\"image\" src=\"https://www.paypalobjects.com/en_US/i/btn/btn_donate_LG.gif\" border=\"0\" name=\"submit\" title=\"PayPal - The safer, easier way to pay online!\" alt=\"Donate with PayPal button\" />
<img alt=\"\" border=\"0\" src=\"https://www.paypal.com/en_PL/i/scr/pixel.gif\" width=\"1\" height=\"1\" />
</form>".$lang->reputationlevels_desc;
	
	$information = array(
		"name"				=> $lang->reputationlevels,
		"description"		=> $lang->reputationlevels_desc,
		"website"			=> "http://supryk.eu/",
		"author"			=> "Krzysztof \"Supryk\" Supryczyński",
		"authorsite"		=> "http://supryk.eu/",
		"version"			=> "2.2",
		"compatibility"		=> "18*",
		"codename"			=> "reputationlevels",
	);
	
	return $information;
}

function reputationlevels_is_installed()
{
    global $db;
	
	$num_rows = $db->num_rows($db->simple_select("settinggroups", "*", "name = \"reputationlevels\""));
	
	return $num_rows;
}

function reputationlevels_install()
{
	global $db, $lang, $mybb;
	$lang->load("config_reputationlevels");
	
	if(!$db->table_exists("reputationlevels"))
	{
		$db->write_query("CREATE TABLE ".TABLE_PREFIX."reputationlevels (
			`lid` int(10) unsigned NOT NULL AUTO_INCREMENT,
			`title` varchar(120) NOT NULL DEFAULT '',
			`reputation` int(10) NOT NULL DEFAULT '0',
			PRIMARY KEY (`lid`)
		) ENGINE=MyISAM ".$db->build_create_table_collation().";");
		
		$reputationlevels = array();
	
		$reputationlevels[] = array(
		//	"lid"				=> "",
			"title"				=> $db->escape_string($lang->reputationlevels_negative_level_2),
			"reputation" 	=> $db->escape_string("-20"),
		);
		
		$reputationlevels[] = array(
		//	"lid"				=> "",
			"title"				=> $db->escape_string($lang->reputationlevels_negative_level_1),
			"reputation" 	=> $db->escape_string("-10"),
		);
		
		$reputationlevels[] = array(
		//	"lid"				=> "",
			"title"				=> $db->escape_string($lang->reputationlevels_neutral_level_1),
			"reputation" 	=> $db->escape_string("0"),
		);
		
		$reputationlevels[] = array(
		//	"lid"				=> "",
			"title"				=> $db->escape_string($lang->reputationlevels_positive_level_1),
			"reputation" 	=> $db->escape_string("1"),
		);
		
		$reputationlevels[] = array(
		//	"lid"				=> "",
			"title"				=> $db->escape_string($lang->reputationlevels_positive_level_2),
			"reputation" 	=> $db->escape_string("10"),
		);
		$db->insert_query_multiple("reputationlevels", $reputationlevels);
	}
	
	update_reputationlevels();
	
	$max_disporder = $db->fetch_field($db->simple_select("settinggroups", "MAX(disporder) AS max_disporder"), "max_disporder");
	
	$settinggroup = array(
	//	"gid"					=> "",
		"name" 				=> "reputationlevels", 
		"title" 				=> $db->escape_string($lang->setting_group_reputationlevels),
		"description"		=> $db->escape_string($lang->setting_group_reputationlevels_desc),
		"disporder" 		=> $max_disporder + 1,
		"isdefault"			=> "0",
	);
	$gid = $db->insert_query("settinggroups", $settinggroup);
	
	$settings = array();
	
	$settings[] = array(
	//	"sid"					=> "",
		"name"				=> "reputationlevels_onoff",
		"title"					=> $db->escape_string($lang->setting_reputationlevels_onoff),
		"description"		=> $db->escape_string($lang->setting_reputationlevels_onoff_desc),
		"optionscode"	=> "onoff",
		"value"				=> "1",
		"disporder"		=> "1",
		"gid"					=> $gid,
		"isdefault"			=> "0",
	);
	
	$settings[] = array(
	//	"sid"					=> "",
		"name"				=> "reputationlevels_postbit_onoff",
		"title"					=> $db->escape_string($lang->setting_reputationlevels_postbit_onoff),
		"description"		=> $db->escape_string($lang->setting_reputationlevels_postbit_onoff_desc),
		"optionscode"	=> "onoff",
		"value"				=> "1",
		"disporder"		=> "2",
		"gid"					=> $gid,
		"isdefault"			=> "0",
	);
	
	$settings[] = array(
	//	"sid"					=> "",
		"name"				=> "reputationlevels_member_profile_onoff",
		"title"					=> $db->escape_string($lang->setting_reputationlevels_member_profile_onoff),
		"description"		=> $db->escape_string($lang->setting_reputationlevels_member_profile_onoff_desc),
		"optionscode"	=> "onoff",
		"value"				=> "1",
		"disporder"		=> "3",
		"gid"					=> $gid,
		"isdefault"			=> "0",
	);
	
	$settings[] = array(
	//	"sid"					=> "",
		"name"				=> "reputationlevels_misc_onoff",
		"title"					=> $db->escape_string($lang->setting_reputationlevels_misc_onoff),
		"description"		=> $db->escape_string($lang->setting_reputationlevels_misc_onoff_desc),
		"optionscode"	=> "onoff",
		"value"				=> "1",
		"disporder"		=> "4",
		"gid"					=> $gid,
		"isdefault"			=> "0",
	);
	
	$db->insert_query_multiple("settings", $settings);
	
	rebuild_settings();
	
	$templategroup = array(
	//	"gid"			   => "",
        "prefix"        => "reputationlevels",
        "title"            => $db->escape_string("<lang:reputationlevels_templates>"),
    );
    $db->insert_query("templategroups", $templategroup);

	$templates = array();

	$templates[] = array(
	//	"tid"			 	  => "",
		"title" 				=> "reputationlevels_postbit_negative",
		"template" 		=> $db->escape_string('<br /><br /><span class="reputationlevels_postbit postbit_negative">{$lang->reputationlevels_reputation} <a href="reputation.php?uid={$reputationlevel[\'uid\']}" style="color: #fff; text-decoration: none;">{$reputationlevel[\'reputation\']}</a><br />{$reputationlevel[\'title\']}</span>'),
		"sid" 				=> "-2",
		"version" 				=> "1.8",
		"status" 				=> "",
		"dateline" 				=> TIME_NOW,
	);
	
	$templates[] = array(
	//	"tid"			 	  => "",
		"title" 				=> "reputationlevels_postbit_neutral",
		"template" 		=> $db->escape_string('<br /><br /><span class="reputationlevels_postbit postbit_neutral">{$lang->reputationlevels_reputation} <a href="reputation.php?uid={$reputationlevel[\'uid\']}" style="color: #fff; text-decoration: none;">{$reputationlevel[\'reputation\']}</a><br />{$reputationlevel[\'title\']}</span>'),
		"sid" 				=> "-2",
		"version" 				=> "1.8",
		"status" 				=> "",
		"dateline" 				=> TIME_NOW,
	);

	$templates[] = array(
	//	"tid"			 	  => "",
		"title" 				=> "reputationlevels_postbit_positive",
		"template" 		=> $db->escape_string('<br /><br /><span class="reputationlevels_postbit postbit_positive">{$lang->reputationlevels_reputation} <a href="reputation.php?uid={$reputationlevel[\'uid\']}" style="color: #fff; text-decoration: none;">{$reputationlevel[\'reputation\']}</a><br />{$reputationlevel[\'title\']}</span>'),
		"sid" 				=> "-2",
		"version" 				=> "1.8",
		"status" 				=> "",
		"dateline" 				=> TIME_NOW,
	);
	
	$templates[] = array(
	//	"tid"			 	  => "",
		"title" 				=> "reputationlevels_member_profile_negative",
		"template" 		=> $db->escape_string('<br /><br /><span class="reputationlevels_member_profile member_profile_negative">{$lang->reputationlevels_reputation} <a href="reputation.php?uid={$reputationlevel[\'uid\']}" style="color: #fff; text-decoration: none;">{$reputationlevel[\'reputation\']}</a><br />{$reputationlevel[\'title\']}</span>'),
		"sid" 				=> "-2",
		"version" 				=> "1.8",
		"status" 				=> "",
		"dateline" 				=> TIME_NOW,
	);
	
	$templates[] = array(
	//	"tid"			 	  => "",
		"title" 				=> "reputationlevels_member_profile_neutral",
		"template" 		=> $db->escape_string('<br /><br /><span class="reputationlevels_member_profile member_profile_neutral">{$lang->reputationlevels_reputation} <a href="reputation.php?uid={$reputationlevel[\'uid\']}" style="color: #fff; text-decoration: none;">{$reputationlevel[\'reputation\']}</a><br />{$reputationlevel[\'title\']}</span>'),
		"sid" 				=> "-2",
		"version" 				=> "1.8",
		"status" 				=> "",
		"dateline" 				=> TIME_NOW,
	);
	
	$templates[] = array(
	//	"tid"			 	  => "",
		"title" 				=> "reputationlevels_member_profile_positive",
		"template" 		=> $db->escape_string('<br /><br /><span class="reputationlevels_member_profile member_profile_positive">{$lang->reputationlevels_reputation} <a href="reputation.php?uid={$reputationlevel[\'uid\']}" style="color: #fff; text-decoration: none;">{$reputationlevel[\'reputation\']}</a><br />{$reputationlevel[\'title\']}</span>'),
		"sid" 				=> "-2",
		"version" 				=> "1.8",
		"status" 				=> "",
		"dateline" 				=> TIME_NOW,
	);
	
	$templates[] = array(
	//	"tid"			 	  => "",
		"title" 				=> "reputationlevels",
		"template" 		=> $db->escape_string('<html>
	<head>
		{$headerinclude}
		<title>{$mybb->settings[\'bbname\']} - {$lang->reputationlevels}</title>
	</head>
	<body>
		{$header}
		<table border="0" cellspacing="{$theme[\'borderwidth\']}" cellpadding="{$theme[\'tablespace\']}" class="tborder">
			<tr>
				<td class="thead" colspan="3"><strong>{$lang->reputationlevels}</strong></td>
			</tr>
			<tr>
				<td class="trow2" align="center" width="33%"><span class="reputationlevels_postbit postbit_negative">{$lang->reputationlevels_reputation} -3<br />{$lang->reputationlevels_negative_level_1}</span></td>
				<td class="trow2" align="center" width="34%"><span class="reputationlevels_postbit postbit_neutral">{$lang->reputationlevels_reputation} 0<br />{$lang->reputationlevels_neutral_level_1}</span></td>
				<td class="trow2" align="center" width="33%"><span class="reputationlevels_postbit postbit_positive">{$lang->reputationlevels_reputation} 3<br />{$lang->reputationlevels_positive_level_1}</span></td>
			</tr>
			{$reputationlevels_level}
		</table>
		<br />
		{$footer}
	</body>
</html>'),
		"sid" 				=> "-2",
		"version" 				=> "1.8",
		"status" 				=> "",
		"dateline" 				=> TIME_NOW,
	);
	
	$templates[] = array(
	//	"tid"			 	  => "",
		"title" 				=> "reputationlevels_level",
		"template" 		=> $db->escape_string('<tr>
				<td class="trow2" align="center" width="50%" colspan="2">{$reputationlevel[\'title\']}</td>
				<td class="trow2" align="center" width="50%" colspan="2">{$reputationlevel[\'reputation\']}</td>
			</tr>'),
		"sid" 				=> "-2",
		"version" 				=> "1.8",
		"status" 				=> "",
		"dateline" 				=> TIME_NOW,
	);
	
	$db->insert_query_multiple("templates", $templates);
	
	$style = ".reputationlevels_postbit {
	background: url(images/reputationlevels/highlight_faint.png) repeat-x;
	background-position: 0 0;
	font-weight: bold;
	padding: 3px 8px;
	display: inline-block;
	-moz-border-radius: 3px;
	-webkit-border-radius: 3px;
	border-radius: 3px;
	border-style: solid;
	border-width: 1px;
	text-shadow: 1px 1px 0 rgba(0, 0, 0, 0.6);
	color: #fff;
	-webkit-box-shadow: 0 1px 0 rgba(255, 255, 255, 0.3) inset;
	-moz-box-shadow: 0 1px 0 rgba(255, 255, 255, 0.3) inset;
	box-shadow: 0 1px 0 rgba(255, 255, 255, 0.3) inset;
	clear: both;
	text-align: center;
	font-size:1.1em;
	padding: 2px 10px !important;
}

.postbit_negative {
	background-color: #D91313;
	border-color: #8C1313;
}

.postbit_neutral {
	background-color: #C0C0C0;
	border-color: #A79D9D;
}

.postbit_positive {
	background-color: #95D913;
	border-color: #638C13;
}

.reputationlevels_member_profile {
	background: url(images/reputationlevels/highlight_faint.png) repeat-x;
	background-position: 0 0;
	font-weight: bold;
	padding: 3px 8px;
	display: inline-block;
	-moz-border-radius: 3px;
	-webkit-border-radius: 3px;
	border-radius: 3px;
	border-style: solid;
	border-width: 1px;
	text-shadow: 1px 1px 0 rgba(0, 0, 0, 0.6);
	color: #fff;
	-webkit-box-shadow: 0 1px 0 rgba(255, 255, 255, 0.3) inset;
	-moz-box-shadow: 0 1px 0 rgba(255, 255, 255, 0.3) inset;
	box-shadow: 0 1px 0 rgba(255, 255, 255, 0.3) inset;
	clear: both;
	text-align: center;
	font-size:1.1em;
	padding: 2px 10px !important;
}

.member_profile_negative {
	background-color: #D91313;
	border-color: #8C1313;
}

.member_profile_neutral {
	background-color: #C0C0C0;
	border-color: #A79D9D;
}

.member_profile_positive {
	background-color: #95D913;
	border-color: #638C13;
}";
	
	$stylesheet = array(
	//	"sid"         		=> "",
		"name"         		=> "reputationlevels.css",
		"cachefile"		=> "reputationlevels.css",
		"tid"         			=> "1",
		"attachedto"   	=> "showthread.php|member.php|newreply.php|editpost.php|private.php|newthread.php|modcp.php|announcements.php|misc.php",
		"stylesheet"   	=> $db->escape_string($style),
		'lastmodified' 	=> TIME_NOW
	);

	$db->insert_query("themestylesheets", $stylesheet);
	
	require_once MYBB_ADMIN_DIR."inc/functions_themes.php";

	cache_stylesheet(1, "reputationlevels.css", $style);
	update_theme_stylesheet_list(1, false, true);
	
	change_admin_permission("config", "reputationlevels", 1);
}

function reputationlevels_uninstall()
{
    global $db, $mybb, $cache, $page, $lang;
	$lang->load("config_reputationlevels");
	
	if($mybb->request_method != 'post')
	{
		$page->output_confirm_action("index.php?module=config-plugins&action=deactivate&uninstall=1&plugin=reputationlevels", $lang->reputationlevels_uninstall_message, $lang->reputationlevels_uninstall);
	}
	
	if($db->table_exists("reputationlevels") && !isset($mybb->input['no']))
	{
		$db->drop_table("reputationlevels");
	}
	
	$cache->delete("reputationlevels");
	
	$db->delete_query("settinggroups", "name = \"reputationlevels\"");
	$db->delete_query("settings", "name LIKE \"reputationlevels%\"");
	rebuild_settings();
	$db->delete_query("templategroups", "prefix = \"reputationlevels\"");
	$db->delete_query("templates", "title LIKE \"reputationlevels%\"");
	$db->delete_query("themestylesheets", "name= \"reputationlevels.css\"");
	
	require_once MYBB_ADMIN_DIR."inc/functions_themes.php";
	
	$query = $db->simple_select("themes", "tid");
    while($theme = $db->fetch_array($query))
    {
		@unlink(MYBB_ROOT."cache/themes/theme{$theme['tid']}/reputationlevels.css");
		@unlink(MYBB_ROOT."cache/themes/theme{$theme['tid']}/reputationlevels.min.css");
        update_theme_stylesheet_list($theme['tid'], false, true); 
    }
	
	change_admin_permission("config", "reputationlevels", 0);
}

function reputationlevels_activate()
{		
	reputationlevels_deactivate();
	
	find_replace_templatesets("postbit_classic", '#'.preg_quote('{$post[\'user_details\']}').'#', '{$post[\'user_details\']}{$post[\'reputationlevel\']}');
	find_replace_templatesets("postbit", '#'.preg_quote('{$post[\'user_details\']}').'#', '{$post[\'user_details\']}{$post[\'reputationlevel\']}');
	find_replace_templatesets("member_profile", '#'.preg_quote('{$avatar}').'#', '{$avatar}{$memprofile[\'reputationlevel\']}');
}

function reputationlevels_deactivate()
{
	include MYBB_ROOT."/inc/adminfunctions_templates.php";
	
	find_replace_templatesets('postbit_classic', '#' . preg_quote('{$post[\'reputationlevel\']}') . '#', '', 0);
	find_replace_templatesets('postbit', '#' . preg_quote('{$post[\'reputationlevel\']}') . '#', '', 0);
	find_replace_templatesets('member_profile', '#' . preg_quote('{$memprofile[\'reputationlevel\']}') . '#', '', 0);
}

function reputationlevels_admin_lang_load()
{
    global $lang;
    $lang->load("config_reputationlevels");
} 

function reputationlevels_admin_config_menu(&$sub_menu)
{
    global $lang;
	$lang->load("config_reputationlevels");
	
    $sub_menu[] = array("id" => "reputationlevels", "title" => $lang->reputationlevels, "link" => "index.php?module=config-reputationlevels");
} 

function reputationlevels_admin_config_action_handler(&$actions)
{
    $actions['reputationlevels'] = array("active" => "reputationlevels", "file" => "reputationlevels.php");
}

function reputationlevels_admin_config_permissions(&$admin_permissions)
{
    global $lang;
    $lang->load("config_reputationlevels");
	
    $admin_permissions['reputationlevels'] = $lang->reputationlevels_admin_permissions;
}

function reputationlevels_postbit(&$post)
{
	global $mybb, $cache, $lang, $templates;
	$lang->load("reputationlevels");
	
	if($mybb->settings['reputationlevels_onoff'] != "1")
	{
		return;
	}
	
	if($mybb->settings['reputationlevels_postbit_onoff'] != "1")
	{
		return;
	}

	if($post['uid'] == "0")
	{	
		return;
	}
	
	$post['user_details'] = str_replace($post['replink'], "", $post['user_details']);
		
	static $levels;
	static $levels_check = false;
		
	if(!$levels_check)
	{			
		$levels = $cache->read("reputationlevels");
			
		$levels_check = true;
	}
		
	if(isset($levels))
	{
		$reputationlevel = array_slice(array_filter($levels, function($val) use ($post) { return $val['reputation'] <= $post['reputation']; }), -1); 
			
		$reputationlevel['title'] = htmlspecialchars_uni($reputationlevel['0']['title']);
		$reputationlevel['reputation'] = $post['reputation'];
		$reputationlevel['uid'] = $post['uid'];

		if($reputationlevel['reputation'] < '0')
		{
			eval("\$post['reputationlevel'] = \"".$templates->get("reputationlevels_postbit_negative")."\";");
		}
		elseif($reputationlevel['reputation'] == '0')
		{
			eval("\$post['reputationlevel'] = \"".$templates->get("reputationlevels_postbit_neutral")."\";");
		}
		elseif($reputationlevel['reputation'] > '0')
		{
			eval("\$post['reputationlevel'] = \"".$templates->get("reputationlevels_postbit_positive")."\";");
		}
	}
}

function reputationlevels_member_profile()
{
	global $mybb, $cache, $lang, $templates, $memprofile, $reputation;
	$lang->load("reputationlevels");
	
	if($mybb->settings['reputationlevels_onoff'] != "1")
	{
		return;
	}
	
	if($mybb->settings['reputationlevels_member_profile_onoff'] != "1")
	{
		return;
	}

	if($memprofile['uid'] == "0")
	{
		return;
	}
	
	$reputation = "";
	
	$levels = $cache->read("reputationlevels");
	
	if(isset($levels))
	{
		$reputationlevel = array_slice(array_filter($levels, function($val) use ($memprofile) { return $val['reputation'] <= $memprofile['reputation']; }), -1);
			
		$reputationlevel['title'] = htmlspecialchars_uni($reputationlevel['0']['title']);
		$reputationlevel['reputation'] = $memprofile['reputation'];
		$reputationlevel['uid'] = $memprofile['uid'];

		if($reputationlevel['reputation'] < "0")
		{
			eval("\$memprofile['reputationlevel'] = \"".$templates->get("reputationlevels_member_profile_negative")."\";");
		}
		elseif($reputationlevel['reputation'] == "0")
		{
			eval("\$memprofile['reputationlevel'] = \"".$templates->get("reputationlevels_member_profile_neutral")."\";");
		}
		elseif($reputationlevel['reputation'] > "0")
		{
			eval("\$memprofile['reputationlevel'] = \"".$templates->get("reputationlevels_member_profile_positive")."\";");
		}
	}
}

function reputationlevels_misc()
{
	global $mybb, $cache, $lang, $theme, $templates, $header, $footer, $headerinclude;
	$lang->load("reputationlevels");
	
	if($mybb->settings['reputationlevels_onoff'] != "1")
	{
		return;
	}
	
	if($mybb->settings['reputationlevels_misc_onoff'] != "1")
	{
		return;
	}
	
	if($mybb->settings['reputationlevels_member_profile_onoff'] != "1" && $mybb->settings['reputationlevels_postbit_onoff'] != "1")
	{
		return;
	}
	
	if($mybb->get_input("action") != "reputationlevels")
	{
		return;
	}
	
	$levels = $cache->read("reputationlevels");
	
	if(!isset($levels))
	{
		return;
	}
	
	foreach($levels as $reputationlevel)
	{
		$reputationlevel['title'] = htmlspecialchars_uni($reputationlevel['title']);
		$reputationlevel['reputation'] = $reputationlevel['reputation'];
		eval("\$reputationlevels_level .= \"".$templates->get("reputationlevels_level")."\";");
	}

	add_breadcrumb($lang->reputationlevels, "misc.php?action=reputationlevels");
	eval("\$page = \"".$templates->get("reputationlevels")."\";");
	output_page($page);
	exit;
}

function update_reputationlevels()
{
	global $db, $cache;

	$reputations = array();

	$query = $db->simple_select("reputationlevels", "*", "", array('order_by' => 'reputation'));
	while($reputation = $db->fetch_array($query))
	{
		$reputations[$reputation['lid']] = array(
			"lid" => $reputation['lid'],
			"title" => $reputation['title'],
			"reputation" => $reputation['reputation'],
		);
	}

	$cache->update("reputationlevels", $reputations);
}

function reputationlevels_global_start()
{
	global $templatelist;
	
	if(in_array(THIS_SCRIPT, explode("," ,"showthread.php,newreply.php,editpost.php,private.php,newthread.php,modcp.php,announcements.php")))
	{	
		if(isset($templatelist))
		{
			$templatelist .= ", ";
		}
		
		$templatelist .= "reputationlevels_postbit_negative, reputationlevels_postbit_neutral, reputationlevels_postbit_positive";
	}

	if(in_array(THIS_SCRIPT, explode("," ,"member.php")))
	{	
		if(isset($templatelist))
		{
			$templatelist .= ", ";
		}
		
		$templatelist .= "reputationlevels_member_profile_negative, reputationlevels_member_profile_neutral, reputationlevels_member_profile_positive";
	}
	
	if(in_array(THIS_SCRIPT, explode("," ,"misc.php")))
	{	
		if(isset($templatelist))
		{
			$templatelist .= ", ";
		}
		
		$templatelist .= "reputationlevels, reputationlevels_level";
	}
}

/********************************************************************************************************************************
*
* Say thanks to plugin author - paste link to author website.
* Please don't remove this code if you didn't make donate.
* It's the only way to say thanks without donate.
*
********************************************************************************************************************************/
function reputationlevels_pre_output_page(&$content)
{
    global $session, $thanksSupryk, $lang;
	$lang->load("reputationlevels");
        
    if(!isset($thanksSupryk) && $session->is_spider)
    {
        $thx = '<div style="margin:auto; text-align:center;">'.$lang->reputationlevels_thanks.'</div></body>';
        $content = str_replace('</body>', $thx, $content);
        $thanksSupryk = true;
    }
}